@@ -86,6 +86,7 @@ environ_whitelist += [
     "ACCEPT_LICENSE",
     "BASH_ENV",
     "BASH_FUNC____in_portage_iuse%%",
+    "BINPKG_FORMAT",
     "BROOT",
     "BUILD_PREFIX",
     "COLUMNS",
@@ -339,7 +340,6 @@ environ_filter += [
     "RESUMECOMMAND_HTTPS",
     "RESUMECOMMAND_RSYNC",
     "RESUMECOMMAND_SFTP",
-    "SIGNED_OFF_BY",
     "UNINSTALL_IGNORE",
     "USE_EXPAND_HIDDEN",
     "USE_ORDER",
